Include information about hazard and survival distribution for each individual in a dataset.
# S3 method for survival_ln_mixture
augment(x, newdata, eval_time, ...)A tibble::tibble() with the original covariates and ther survvial and hazard
distributions.
A survival_ln_mixture object.
A base::data.frame() or tibble::tiblle() containing all
the original predictors used to create x.
a vector with the times where the hazard and survival distribuition will be evaluated.
Not used.