Predict from a lognormal_em Mixture Model fitted using EM algorithm.
# S3 method for survival_ln_mixture_em
predict(object, new_data, type, eval_time, ...)A tibble of predictions. The number of rows in the tibble is guaranteed
to be the same as the number of rows in new_data.
A survival_ln_mixture_em object.
A data frame or matrix of new predictors.
A single character. The type of predictions to generate. Valid options are:
"survival" for the survival probability.
"hazard" for the hazard theoretical hazard.
For type = "hazard" or type = "survival", the times for the distribution.
Not used, but required for extensibility.