tidy.survival_ln_mixture_em: Tidying method for a Lognormal Mixture model (fitted via Expectation-Maximization algorithm).
Description
These method tidy the estimates from survival_ln_mixture fits into a short summary. It doesn't contain uncertainty estimates since it's a likelihood maximization algorithm.
A data.frame without rownames. When effects="fixed" (the default), tidy.survival_ln_mixutre
returns one row for each coefficient for each component of the mixture with two columns:
term
The name of the corresponding term in the model.
estimate
A point estimate of the coefficient (last iteration value).
Setting effects="auxiliary" will select the precision and proportion of mixture components parameters.
Arguments
x
Fitted model object (survival_ln_mixture_em).
effects
A character vector including one or more of "fixed" and "auxiliary.